@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2ORuleFit import H2ORuleFit
 
@@ -55,6 +55,7 @@ class H2ORuleFitClassifier(H2ORuleFit):
                  distribution="AUTO",
                  labelCol="label",
                  weightCol=None,
+                 maxCategoricalLevels=10,
                  aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2ORuleFit, self).__init__()
